function [ret,x0,str,ts,xts]=survsiml(t,x,u,flag);
%SURVSIML	is the M-file description of the SIMULINK system named SURVSIML.
%	The block-diagram can be displayed by typing: SURVSIML.
%
%	SYS=SURVSIML(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SURVSIML to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SURVSIML with a FLAG of zero:
%	[SIZES]=SURVSIML([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[24,72,1230,969])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '30000')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '2')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['DETUMBLING PUIS MISE EN SPIN VERS UN SPIN DE CONSIGNE',13,'  UTILISATION DU QUATERNION D''ATTITUDE']])
set_param([sys,'/',['DETUMBLING PUIS MISE EN SPIN VERS UN SPIN DE CONSIGNE',13,'  UTILISATION DU QUATERNION D''ATTITUDE']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22)
set_param([sys,'/',['DETUMBLING PUIS MISE EN SPIN VERS UN SPIN DE CONSIGNE',13,'  UTILISATION DU QUATERNION D''ATTITUDE']],...
		'position',[625,0,630,5])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','[vp0 vq0 vr0 qt00 qt10 qt20 qt30]',...
		'position',[645,414,745,466])

add_block('built-in/Note',[sys,'/',['Stabilisation par la drive du champ magntique terrestre, sans roue',13,'mais avec mise en spin  vitesse et axe choisis, simulation initiale regspin0.m  ']])
set_param([sys,'/',['Stabilisation par la drive du champ magntique terrestre, sans roue',13,'mais avec mise en spin  vitesse et axe choisis, simulation initiale regspin0.m  ']],...
		'ForeGround',5,...
		'Font Name','Arial Narrow')
set_param([sys,'/',['Stabilisation par la drive du champ magntique terrestre, sans roue',13,'mais avec mise en spin  vitesse et axe choisis, simulation initiale regspin0.m  ']],...
		'Font Weight','bold',...
		'Font Size',18)
set_param([sys,'/',['Stabilisation par la drive du champ magntique terrestre, sans roue',13,'mais avec mise en spin  vitesse et axe choisis, simulation initiale regspin0.m  ']],...
		'position',[608,75,613,80])

add_block('built-in/Note',[sys,'/',['L''initialisation',13,' lance surv1dat.m']])
set_param([sys,'/',['L''initialisation',13,' lance surv1dat.m']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1065,525,1070,530])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris\nCAS GENERAL',...
		'Mask Dialogue','eval(''surv1dat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[965,455,1180,526])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',7,...
		'position',[1055,403,1090,437])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[395,325,400,330])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[390,510,395,515])


%     Subsystem  'F(X,t) pour le quaternion'.

new_system([sys,'/','F(X,t) pour le quaternion'])
set_param([sys,'/','F(X,t) pour le quaternion'],'Location',[588,239,931,333])

add_block('built-in/Note',[sys,'/',['F(X,t) pour le quaternion/Drive du quaternion d''attitude']])
set_param([sys,'/',['F(X,t) pour le quaternion/Drive du quaternion d''attitude']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','F(X,t) pour le quaternion/Outport'])
set_param([sys,'/','F(X,t) pour le quaternion/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','F(X,t) pour le quaternion/Inport'])
set_param([sys,'/','F(X,t) pour le quaternion/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour le quaternion/deriv_qt.m'])
set_param([sys,'/','F(X,t) pour le quaternion/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','F(X,t) pour le quaternion'],[225,55;255,55])
add_line([sys,'/','F(X,t) pour le quaternion'],[105,55;145,55])
set_param([sys,'/','F(X,t) pour le quaternion'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'F(X,t) pour le quaternion'.

set_param([sys,'/','F(X,t) pour le quaternion'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[100,458,315,562])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[460,294,520,581])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[530,345,535,350])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[530,505,535,510])


%     Subsystem  'F(X,t) pour la rotation'.

new_system([sys,'/','F(X,t) pour la rotation'])
set_param([sys,'/','F(X,t) pour la rotation'],'Location',[-8,125,1175,871])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/F(X,t) POUR LA PARTIE CONCERNANT LA SEULE ROTATION'])
set_param([sys,'/','F(X,t) pour la rotation/F(X,t) POUR LA PARTIE CONCERNANT LA SEULE ROTATION'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[630,40,635,45])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain3'])
set_param([sys,'/','F(X,t) pour la rotation/Gain3'],...
		'hide name',0,...
		'Gain','K_poinsot',...
		'position',[835,338,875,372])


%     Subsystem  ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],'Location',[4,207,1271,813])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/B']],...
		'position',[510,425,515,430])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[140,515,145,520])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[800,382,835,408])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,399,885,404])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,277,695,282])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[770,438,830,472])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[375,315,490,365])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[895,440,1015,470])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,246,250,251])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[640,378,700,412])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[540,286,585,504])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[320,288,350,392])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[130,293,275,317])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[130,328,275,352])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[130,363,275,387])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/M']],...
		'position',[525,315,530,320])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[785,318,930,342])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[785,283,930,307])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[785,248,930,272])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[975,243,1005,347])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[895,195,900,200])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[795,158,940,182])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[795,123,940,147])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[795,88,940,112])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[985,83,1015,187])


%     Subsystem  ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,288,1041,757])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[220,120;245,120])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[430,120;480,120])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[240,458,440,532])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[385,95,390,100])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[20,485,40,505])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1090,254,1125,361])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1200,300,1220,320])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[665,505,670,510])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[945,540,950,545])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE',...
		'position',[630,554,805,606])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[45,495;235,495])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[840,395;1055,395;1055,320;1085,320])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[705,395;735,395;735,455;765,455])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[735,395;795,395])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[835,455;890,455])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[590,395;635,395])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[445,495;470,495;470,450;535,450])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[495,340;535,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[355,340;370,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,305;315,305])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,340;315,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,375;315,375])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,100;980,100])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,135;980,135])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,170;980,170])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,260;970,260])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,295;970,295])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1010,295;1085,295])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,330;970,330])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1020,135;1075,135;1085,270])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[75,495;75,580;625,580])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1130,310;1195,310])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[810,580;1070,580;1070,345;1085,345])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[280,372,410,428])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain2'])
set_param([sys,'/','F(X,t) pour la rotation/Gain2'],...
		'position',[505,290,550,320])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/La rgulation en ''BPOINT'' seule avec l''oscillation finale au double de la pulsation orbitale']])
set_param([sys,'/',['F(X,t) pour la rotation/La rgulation en ''BPOINT'' seule avec l''oscillation finale au double de la pulsation orbitale']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/La rgulation en ''BPOINT'' seule avec l''oscillation finale au double de la pulsation orbitale']],...
		'position',[650,705,655,710])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/La conservation de l''nergie',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/La conservation de l''nergie',13,'']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[390,675,395,680])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Le mouvement de Poinsot  ( matrice d''inertie diagonale de rvolution +  aucun couple )']])
set_param([sys,'/',['F(X,t) pour la rotation/Le mouvement de Poinsot  ( matrice d''inertie diagonale de rvolution +  aucun couple )']],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[645,650,650,655])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Cette simulation permet de vrifier :'])
set_param([sys,'/','F(X,t) pour la rotation/Cette simulation permet de vrifier :'],...
		'ForeGround',3,...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[360,620,365,625])


%     Subsystem  'F(X,t) pour la rotation/Rgulation B-dot'.

new_system([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],'Location',[4,44,1218,719])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/REGULATION PAR LA DERIVEE DE B ET UN GAIN MATRICIEL'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/REGULATION PAR LA DERIVEE DE B ET UN GAIN MATRICIEL'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[555,10,560,15])

add_block('built-in/Relational Operator',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Relational',13,'Operator']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Relational',13,'Operator']],...
		'position',[670,838,700,862])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Sortie du couple gnr',13,'par la commande drive de B']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Sortie du couple gnr',13,'par la commande drive de B']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[1105,790,1110,795])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Mux2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Mux2'],...
		'hide name',0,...
		'inputs','3',...
		'position',[925,269,955,411])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Mux1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Mux1'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[980,278,1010,527])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Outport'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Outport'],...
		'position',[1135,385,1155,405])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/To Workspace'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/To Workspace'],...
		'hide name',0,...
		'mat-name','cpl_deriv',...
		'buffer','points_trace',...
		'position',[1110,300,1190,320])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Couple magntique',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Couple magntique',13,'']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[1030,378,1090,412])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/To Workspace2'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/To Workspace2'],...
		'hide name',0,...
		'mat-name','my_deriv',...
		'buffer','points_trace',...
		'position',[945,195,1025,215])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/To Workspace3'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/To Workspace3'],...
		'hide name',0,...
		'mat-name','mz_deriv',...
		'buffer','points_trace',...
		'position',[945,230,1025,250])


%     Subsystem  'F(X,t) pour la rotation/Rgulation B-dot/Subsystem'.

new_system([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],'Location',[4,44,655,587])

add_block('built-in/Relational Operator',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Relational',13,'Operator1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Relational',13,'Operator1']],...
		'hide name',0,...
		'Operator','<=',...
		'position',[195,229,220,296])

add_block('built-in/Clock',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Clock'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Clock'],...
		'hide name',0,...
		'position',[160,235,180,255])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Constant1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Constant1'],...
		'hide name',0,...
		'Value','T_bascule',...
		'position',[85,106,155,134])

add_block('built-in/Clock',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Clock1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Clock1'],...
		'hide name',0,...
		'position',[155,75,175,95])

add_block('built-in/Relational Operator',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Relational',13,'Operator2']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Relational',13,'Operator2']],...
		'hide name',0,...
		'position',[190,69,215,136])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Sum'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Sum'],...
		'hide name',0,...
		'position',[435,144,470,246])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/out_1'],...
		'position',[500,185,520,205])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Moments ',13,'magntiques',13,' gnrer2']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Moments ',13,'magntiques',13,' gnrer2']],...
		'hide name',0,...
		'MATLAB Fcn','momspin1(u)',...
		'Output Width','3',...
		'position',[175,148,235,182])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Moments ',13,'magntiques',13,' gnrer1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Moments ',13,'magntiques',13,' gnrer1']],...
		'hide name',0,...
		'MATLAB Fcn','momspin0(u)',...
		'Output Width','3',...
		'position',[185,308,245,342])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Product'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Product'],...
		'position',[330,75,365,195])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Product1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Product1'],...
		'position',[335,235,370,355])

add_block('built-in/Constant',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Constant'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/Constant'],...
		'hide name',0,...
		'Value','T_bascule',...
		'position',[105,268,175,292])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem/in_1'],...
		'position',[75,350,95,370])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],[100,360;100,165;170,165])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],[100,325;180,325])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],[375,295;395,295;395,220;430,220])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],[370,135;395,135;395,170;430,170])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],[240,165;325,165])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],[220,105;325,105])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],[160,120;185,120])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],[180,85;185,85])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],[250,325;330,325])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],[225,265;330,265])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],[180,280;190,280])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],[185,245;190,245])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],[475,195;495,195])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],...
		'Mask Display','momospin0\npuis\nmomspin1')


%     Finished composite block 'F(X,t) pour la rotation/Rgulation B-dot/Subsystem'.

set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Subsystem'],...
		'position',[585,318,770,362])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/in_1'],...
		'position',[45,285,65,305])


%     Subsystem  ['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_'].

new_system([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_']],'Location',[382,182,1228,651])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/BX BY BZ']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/Clock']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_']],[535,160;555,160])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_']],[75,200;480,200])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_']],[625,160;700,160])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_']],[430,120;480,120])
add_line([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_']],[220,120;245,120])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_'].

set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Champ magntique',13,'en axes satellite_']],...
		'position',[115,258,315,332])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Sortie B',13,'axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Sortie B',13,'axes satellite']],...
		'position',[365,250,370,255])

add_block('built-in/Derivative',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Drive de B',13,'en axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Drive de B',13,'en axes satellite']],...
		'position',[415,260,460,330])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/B''']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/B''']],...
		'position',[480,270,485,275])

add_block('built-in/Mux',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Mux'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Mux'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[500,250,535,425])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/B'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/B'],...
		'position',[460,380,465,385])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Demux1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/Demux1'],...
		'hide name',0,...
		'outputs','3',...
		'position',[805,270,860,410])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Rgulation B-dot/To Workspace1'])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot/To Workspace1'],...
		'hide name',0,...
		'mat-name','mx_deriv',...
		'buffer','points_trace',...
		'position',[940,150,1020,170])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Entre vecteur d''tat ',13,'7 composantes p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/Entre vecteur d''tat ',13,'7 composantes p q r Q']],...
		'position',[100,365,105,370])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Rgulation B-dot/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[605,57,610,62])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[1095,395;1105,310])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[1095,395;1130,395])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[1015,405;1025,395])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[320,295;410,295])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[375,295;375,380;495,380])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[375,380;375,463;975,465])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[70,295;110,295])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[465,295;495,295])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[865,295;920,295])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[865,340;920,340])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[865,385;920,385])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[960,340;975,340])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[910,385;910,240;940,240])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[895,340;895,205;940,205])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[865,295;865,160;935,160])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[540,340;580,340])
add_line([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],[775,340;800,340])
set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],...
		'Mask Display','REGULATION PAR\n\DERIVEE DU CHAMP MAGNETIQUE')


%     Finished composite block 'F(X,t) pour la rotation/Rgulation B-dot'.

set_param([sys,'/','F(X,t) pour la rotation/Rgulation B-dot'],...
		'position',[240,264,460,346])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Suppression de',13,'toutes les',13,'perturbations']])
set_param([sys,'/',['F(X,t) pour la rotation/Suppression de',13,'toutes les',13,'perturbations']],...
		'position',[510,415,515,420])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain'])
set_param([sys,'/','F(X,t) pour la rotation/Gain'],...
		'hide name',0,...
		'position',[495,383,535,417])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Sum2'])
set_param([sys,'/','F(X,t) pour la rotation/Sum2'],...
		'hide name',0,...
		'position',[630,259,675,446])

add_block('built-in/State-Space',[sys,'/',['F(X,t) pour la rotation/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']])
set_param([sys,'/',['F(X,t) pour la rotation/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['F(X,t) pour la rotation/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[695,332,795,378])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/out_1'],...
		'position',[1075,415,1095,435])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Gain1'],...
		'hide name',0,...
		'position',[1020,412,1045,438])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/Sum1'],...
		'position',[920,284,960,566])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/magneto.m1'])
set_param([sys,'/','F(X,t) pour la rotation/magneto.m1'],...
		'hide name',0,...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[560,469,685,521])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Suppression de',13,'tous les couples']])
set_param([sys,'/',['F(X,t) pour la rotation/Suppression de',13,'tous les couples']],...
		'position',[850,295,855,300])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/To Workspace4'])
set_param([sys,'/','F(X,t) pour la rotation/To Workspace4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','quater',...
		'buffer','2500',...
		'position',[320,550,385,580])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Inport'])
set_param([sys,'/','F(X,t) pour la rotation/Inport'],...
		'position',[70,390,90,410])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'position',[100,425,105,430])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/tau',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/tau',13,'']],...
		'position',[80,330,85,335])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Demux'])
set_param([sys,'/','F(X,t) pour la rotation/Demux'],...
		'outputs','[3 4]',...
		'position',[220,465,270,585])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/pqr'])
set_param([sys,'/','F(X,t) pour la rotation/pqr'],...
		'position',[320,465,325,470])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Q'])
set_param([sys,'/','F(X,t) pour la rotation/Q'],...
		'position',[290,530,295,535])
add_line([sys,'/','F(X,t) pour la rotation'],[415,400;490,400])
add_line([sys,'/','F(X,t) pour la rotation'],[275,495;555,495])
add_line([sys,'/','F(X,t) pour la rotation'],[275,555;305,555;315,565])
add_line([sys,'/','F(X,t) pour la rotation'],[965,425;1015,425])
add_line([sys,'/','F(X,t) pour la rotation'],[1050,425;1070,425])
add_line([sys,'/','F(X,t) pour la rotation'],[95,400;275,400])
add_line([sys,'/','F(X,t) pour la rotation'],[185,400;185,525;215,525])
add_line([sys,'/','F(X,t) pour la rotation'],[185,400;185,305;235,305])
add_line([sys,'/','F(X,t) pour la rotation'],[465,305;500,305])
add_line([sys,'/','F(X,t) pour la rotation'],[555,305;625,305])
add_line([sys,'/','F(X,t) pour la rotation'],[540,400;625,400])
add_line([sys,'/','F(X,t) pour la rotation'],[680,355;690,355])
add_line([sys,'/','F(X,t) pour la rotation'],[800,355;830,355])
add_line([sys,'/','F(X,t) pour la rotation'],[880,355;915,355])
add_line([sys,'/','F(X,t) pour la rotation'],[690,495;915,495])
set_param([sys,'/','F(X,t) pour la rotation'],...
		'Mask Display','F(X , t ) \n\nPOUR LA ROTATION')


%     Finished composite block 'F(X,t) pour la rotation'.

set_param([sys,'/','F(X,t) pour la rotation'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[100,323,325,407])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[4,63,164,72])
open_system([sys,'/','Subsystem'])


%     Subsystem  'Subsystem/Unitaire soleil'.

new_system([sys,'/','Subsystem/Unitaire soleil'])
set_param([sys,'/','Subsystem/Unitaire soleil'],'Location',[133,399,1088,868])

add_block('built-in/Note',[sys,'/',['Subsystem/Unitaire soleil/CALCUL DE L''UNITAIRE SOLEIL Us EN AXES SATELLITE xyz']])
set_param([sys,'/',['Subsystem/Unitaire soleil/CALCUL DE L''UNITAIRE SOLEIL Us EN AXES SATELLITE xyz']],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[490,0,495,5])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/Unitaire soleil/SunitXYZ'])
set_param([sys,'/','Subsystem/Unitaire soleil/SunitXYZ'],...
		'Font Size',12,...
		'MATLAB Fcn','SunitXYZ(u)',...
		'Output Width','3',...
		'Mask Display','UNITAIRE SOLEIL\nEN REPERE ORBITAL',...
		'position',[230,135,405,185])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/Unitaire soleil/Unit_Sat'])
set_param([sys,'/','Subsystem/Unitaire soleil/Unit_Sat'],...
		'MATLAB Fcn','Unit_Sat(u)',...
		'Output Width','3',...
		'position',[590,183,650,217])

add_block('built-in/Clock',[sys,'/','Subsystem/Unitaire soleil/Clock'])
set_param([sys,'/','Subsystem/Unitaire soleil/Clock'],...
		'position',[135,144,170,176])

add_block('built-in/Note',[sys,'/',['Subsystem/Unitaire soleil/Vecteur d''tat ',13,'7 composantes',13,'pqrQ)']])
set_param([sys,'/',['Subsystem/Unitaire soleil/Vecteur d''tat ',13,'7 composantes',13,'pqrQ)']],...
		'position',[145,275,150,280])

add_block('built-in/Inport',[sys,'/','Subsystem/Unitaire soleil/in_1'])
set_param([sys,'/','Subsystem/Unitaire soleil/in_1'],...
		'position',[145,230,165,250])

add_block('built-in/Outport',[sys,'/','Subsystem/Unitaire soleil/out_1'])
set_param([sys,'/','Subsystem/Unitaire soleil/out_1'],...
		'position',[725,190,745,210])

add_block('built-in/Note',[sys,'/','Subsystem/Unitaire soleil/Sortie Ux Uy Uz'])
set_param([sys,'/','Subsystem/Unitaire soleil/Sortie Ux Uy Uz'],...
		'position',[720,135,725,140])

add_block('built-in/Note',[sys,'/','Subsystem/Unitaire soleil/Axes satellite'])
set_param([sys,'/','Subsystem/Unitaire soleil/Axes satellite'],...
		'position',[715,155,720,160])

add_block('built-in/Note',[sys,'/','Subsystem/Unitaire soleil/Equateur au temps 0 s'])
set_param([sys,'/','Subsystem/Unitaire soleil/Equateur au temps 0 s'],...
		'position',[155,115,160,120])

add_block('built-in/Mux',[sys,'/','Subsystem/Unitaire soleil/Mux1'])
set_param([sys,'/','Subsystem/Unitaire soleil/Mux1'],...
		'inputs','[3 7]',...
		'position',[490,120,535,280])

add_block('built-in/Note',[sys,'/','Subsystem/Unitaire soleil/UX UY UZ'])
set_param([sys,'/','Subsystem/Unitaire soleil/UX UY UZ'],...
		'ForeGround',2,...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[310,105,315,110])
add_line([sys,'/','Subsystem/Unitaire soleil'],[540,200;585,200])
add_line([sys,'/','Subsystem/Unitaire soleil'],[170,240;485,240])
add_line([sys,'/','Subsystem/Unitaire soleil'],[655,200;720,200])
add_line([sys,'/','Subsystem/Unitaire soleil'],[175,160;225,160])
add_line([sys,'/','Subsystem/Unitaire soleil'],[410,160;485,160])
set_param([sys,'/','Subsystem/Unitaire soleil'],...
		'Mask Display','UNITAIRE SOLEIL\nEN\nAXES SATELLITE')


%     Finished composite block 'Subsystem/Unitaire soleil'.

set_param([sys,'/','Subsystem/Unitaire soleil'],...
		'position',[140,248,325,322])

add_block('built-in/Clock',[sys,'/','Subsystem/Clock1'])
set_param([sys,'/','Subsystem/Clock1'],...
		'position',[95,77,130,113])

add_block('built-in/Note',[sys,'/',['Subsystem/Sortie B',13,'axes satellite']])
set_param([sys,'/',['Subsystem/Sortie B',13,'axes satellite']],...
		'hide name',0,...
		'position',[225,104,230,109])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem/Couple magntique',13,'3']])
set_param([sys,'/',['Subsystem/Couple magntique',13,'3']],...
		'hide name',0,...
		'MATLAB Fcn','soleil(u)',...
		'Output Width','1',...
		'Mask Display','Soleil',...
		'position',[245,76,335,114])


%     Subsystem  'Subsystem/Energie'.

new_system([sys,'/','Subsystem/Energie'])
set_param([sys,'/','Subsystem/Energie'],'Location',[4,63,164,72])
open_system([sys,'/','Subsystem/Energie'])

add_block('built-in/Note',[sys,'/',['Subsystem/Energie/ENERGIE CALCULEE A PARTIR DES REGULATIONS ALTERNEES',13,'temps > temps_phase3']])
set_param([sys,'/',['Subsystem/Energie/ENERGIE CALCULEE A PARTIR DES REGULATIONS ALTERNEES',13,'temps > temps_phase3']],...
		'Font Name','Arial Narrow',...
		'Font Size',18,...
		'position',[375,15,380,20])

add_block('built-in/Sum',[sys,'/','Subsystem/Energie/Sum'])
set_param([sys,'/','Subsystem/Energie/Sum'],...
		'inputs','+-',...
		'position',[375,122,395,178])

add_block('built-in/Constant',[sys,'/','Subsystem/Energie/Constant'])
set_param([sys,'/','Subsystem/Energie/Constant'],...
		'hide name',0,...
		'Value','temps_energie',...
		'position',[220,152,320,178])

add_block('built-in/Inport',[sys,'/','Subsystem/Energie/in_3'])
set_param([sys,'/','Subsystem/Energie/in_3'],...
		'position',[70,355,90,375])

add_block('built-in/Product',[sys,'/','Subsystem/Energie/Product'])
set_param([sys,'/','Subsystem/Energie/Product'],...
		'position',[610,128,650,212])

add_block('built-in/To Workspace',[sys,'/','Subsystem/Energie/To Workspace11'])
set_param([sys,'/','Subsystem/Energie/To Workspace11'],...
		'hide name',0,...
		'mat-name','puissance_moyenne',...
		'buffer','points_trace',...
		'position',[705,159,835,181])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/Energie/1//u'])
set_param([sys,'/','Subsystem/Energie/1//u'],...
		'MATLAB Fcn','1/u',...
		'Mask Display','INVERSE',...
		'position',[485,131,560,169])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem/Energie/Couple magntique',13,'5']])
set_param([sys,'/',['Subsystem/Energie/Couple magntique',13,'5']],...
		'hide name',0,...
		'MATLAB Fcn','PrecPuis(u)',...
		'Output Width','1',...
		'Mask Display','Puissance',...
		'position',[245,261,335,299])

add_block('built-in/Inport',[sys,'/','Subsystem/Energie/in_2'])
set_param([sys,'/','Subsystem/Energie/in_2'],...
		'Port','3',...
		'position',[70,295,90,315])

add_block('built-in/Inport',[sys,'/','Subsystem/Energie/in_1'])
set_param([sys,'/','Subsystem/Energie/in_1'],...
		'Port','2',...
		'position',[70,240,90,260])

add_block('built-in/Mux',[sys,'/','Subsystem/Energie/Mux6'])
set_param([sys,'/','Subsystem/Energie/Mux6'],...
		'hide name',0,...
		'inputs','[1 3]',...
		'position',[185,224,220,331])

add_block('built-in/Note',[sys,'/','Subsystem/Energie/K_eclipse'])
set_param([sys,'/','Subsystem/Energie/K_eclipse'],...
		'position',[220,340,225,345])

add_block('built-in/Integrator',[sys,'/','Subsystem/Energie/Integrator'])
set_param([sys,'/','Subsystem/Energie/Integrator'],...
		'position',[475,260,505,330])


%     Subsystem  ['Subsystem/Energie/Inner',13,'Product'].

new_system([sys,'/',['Subsystem/Energie/Inner',13,'Product']])
set_param([sys,'/',['Subsystem/Energie/Inner',13,'Product']],'Location',[33,479,253,634])

add_block('built-in/Product',[sys,'/',['Subsystem/Energie/Inner',13,'Product/Product']])
set_param([sys,'/',['Subsystem/Energie/Inner',13,'Product/Product']],...
		'position',[65,55,90,75])

add_block('built-in/Sum',[sys,'/',['Subsystem/Energie/Inner',13,'Product/Sum']])
set_param([sys,'/',['Subsystem/Energie/Inner',13,'Product/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Outport',[sys,'/',['Subsystem/Energie/Inner',13,'Product/out_1']])
set_param([sys,'/',['Subsystem/Energie/Inner',13,'Product/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Inport',[sys,'/',['Subsystem/Energie/Inner',13,'Product/in_2']])
set_param([sys,'/',['Subsystem/Energie/Inner',13,'Product/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Inport',[sys,'/',['Subsystem/Energie/Inner',13,'Product/in_1']])
set_param([sys,'/',['Subsystem/Energie/Inner',13,'Product/in_1']],...
		'position',[15,25,35,45])
add_line([sys,'/',['Subsystem/Energie/Inner',13,'Product']],[40,100;60,70])
add_line([sys,'/',['Subsystem/Energie/Inner',13,'Product']],[40,35;60,60])
add_line([sys,'/',['Subsystem/Energie/Inner',13,'Product']],[95,65;120,65])
add_line([sys,'/',['Subsystem/Energie/Inner',13,'Product']],[150,65;180,65])
set_param([sys,'/',['Subsystem/Energie/Inner',13,'Product']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['Subsystem/Energie/Inner',13,'Product']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['Subsystem/Energie/Inner',13,'Product'].

set_param([sys,'/',['Subsystem/Energie/Inner',13,'Product']],...
		'position',[385,265,415,320])

add_block('built-in/To Workspace',[sys,'/','Subsystem/Energie/To Workspace12'])
set_param([sys,'/','Subsystem/Energie/To Workspace12'],...
		'hide name',0,...
		'mat-name','puissance_inst',...
		'buffer','points_trace',...
		'position',[440,209,545,231])

add_block('built-in/To Workspace',[sys,'/','Subsystem/Energie/To Workspace10'])
set_param([sys,'/','Subsystem/Energie/To Workspace10'],...
		'hide name',0,...
		'mat-name','energie_spin',...
		'buffer','points_trace',...
		'position',[650,284,795,306])
add_line([sys,'/','Subsystem/Energie'],[225,280;240,280])
add_line([sys,'/','Subsystem/Energie'],[510,295;645,295])
add_line([sys,'/','Subsystem/Energie'],[95,250;180,250])
add_line([sys,'/','Subsystem/Energie'],[95,305;180,305])
add_line([sys,'/','Subsystem/Energie'],[150,250;150,135;370,135])
add_line([sys,'/','Subsystem/Energie'],[325,165;370,165])
add_line([sys,'/','Subsystem/Energie'],[400,150;480,150])
add_line([sys,'/','Subsystem/Energie'],[565,150;605,150])
add_line([sys,'/','Subsystem/Energie'],[655,170;700,170])
add_line([sys,'/','Subsystem/Energie'],[95,365;350,365;350,305;380,305])
add_line([sys,'/','Subsystem/Energie'],[340,280;380,280])
add_line([sys,'/','Subsystem/Energie'],[420,295;470,295])
add_line([sys,'/','Subsystem/Energie'],[420,295;420,220;435,220])
add_line([sys,'/','Subsystem/Energie'],[575,295;575,190;605,190])
set_param([sys,'/','Subsystem/Energie'],...
		'Mask Display','ENERGIE PRODUITE')


%     Finished composite block 'Subsystem/Energie'.

set_param([sys,'/','Subsystem/Energie'],...
		'position',[410,162,590,218])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[90,275,110,295])
add_line([sys,'/','Subsystem'],[135,95;240,95])
add_line([sys,'/','Subsystem'],[185,95;185,190;405,190])
add_line([sys,'/','Subsystem'],[340,95;375,95;375,170;405,170])
add_line([sys,'/','Subsystem'],[330,285;375,285;375,210;405,210])
add_line([sys,'/','Subsystem'],[115,285;135,285])
set_param([sys,'/','Subsystem'],...
		'Mask Display','MODULE\n\nENERGIE')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'position',[610,489,815,561])


%     Subsystem  'Extras12'.

new_system([sys,'/','Extras12'])
set_param([sys,'/','Extras12'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras12'],...
		'Mask Display','Courbe en /s\nvitesse angulaire\nAutour de l''axe de spin ')
set_param([sys,'/','Extras12'],...
		'Mask Dialogue','eval(''plot(temps,(p*axe_spin(1)+q*axe_spin(2)+r*axe_spin(3))*180/pi);title(''''Vitesse angulaire axiale du spin'''');text(2500,-3.1,[''''Vitesse de spin vise: '''' num2str(w_spin*180/pi) ''''  /s'''']); grid;figure(gcf)'')')


%     Finished composite block 'Extras12'.

set_param([sys,'/','Extras12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[45,790,250,851])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (/s)',...
		'Mask Dialogue','eval(''plot(temps,p*180/pi,temps,q*180/pi,temps,r*180/pi);grid;figure(gcf)'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[45,720,250,781])


%     Subsystem  'Extras11'.

new_system([sys,'/','Extras11'])
set_param([sys,'/','Extras11'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras11'],...
		'Mask Display','Voir la vitesse angulaire\nde tangage seul (/s)',...
		'Mask Dialogue','eval(''plot(temps,q*180/pi);grid;figure(gcf)'')')


%     Finished composite block 'Extras11'.

set_param([sys,'/','Extras11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1000,725,1205,786])


%     Subsystem  'Extras15'.

new_system([sys,'/','Extras15'])
set_param([sys,'/','Extras15'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras15'],...
		'Mask Display','Voir la courbe\nvitesse precession\n(p+r)^0.5 (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,omega_precession);grid;figure(gcf)'')')


%     Finished composite block 'Extras15'.

set_param([sys,'/','Extras15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[995,650,1200,711])


%     Subsystem  'Extras13'.

new_system([sys,'/','Extras13'])
set_param([sys,'/','Extras13'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras13'],...
		'Mask Display','Voir la courbe\nmoment cintique\n tangage H=Iy*q (mNs)',...
		'Mask Dialogue','eval(''plot(temps,moment_cinetique_2);grid;figure(gcf)'')')


%     Finished composite block 'Extras13'.

set_param([sys,'/','Extras13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[775,725,980,786])


%     Subsystem  'Extras23'.

new_system([sys,'/','Extras23'])
set_param([sys,'/','Extras23'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras23'],...
		'Mask Display','Voir la courbe\nangle de spin\ndes axes y et Y (Degrs)')
set_param([sys,'/','Extras23'],...
		'Mask Dialogue','eval(''plot(temps,angle_y_Y*180/pi);text(2500,90,''''Convergence vidente'''');title(''''Angle entre y et Y, en degrs'''');grid;figure(gcf)'')')


%     Finished composite block 'Extras23'.

set_param([sys,'/','Extras23'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[775,650,980,711])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=bleu\nlacet=magenta')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[295,710,525,796])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);grid;figure(gcf)'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[50,640,250,706])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,650,735,706])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Voir les courbes\nmoments magntiques\nmx, my, mz',...
		'Mask Dialogue','eval(''plot(temps,mx_deriv,temps,my_deriv,temps,mz_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[300,640,525,701])

add_block('built-in/Note',[sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'])
set_param([sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'],...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[615,610,620,615])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,725,735,791])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[185,595,190,600])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[360,590,365,595])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[615,590,620,595])

add_block('built-in/Note',[sys,'/',['Choix des paramtres de la simulation dans surv1dat.m',13,'',13,'- Vitesses grandes ou moyennes ou normales - Simulation de Poinsot - Rglage du gain - axe du pin ',13,' Vitesse du spin - Choix possible de la simulation Bpoint seule ou en parallle avec la mise en spin',13,' ']])
set_param([sys,'/',['Choix des paramtres de la simulation dans surv1dat.m',13,'',13,'- Vitesses grandes ou moyennes ou normales - Simulation de Poinsot - Rglage du gain - axe du pin ',13,' Vitesse du spin - Choix possible de la simulation Bpoint seule ou en parallle avec la mise en spin',13,' ']],...
		'ForeGround',4)
set_param([sys,'/',['Choix des paramtres de la simulation dans surv1dat.m',13,'',13,'- Vitesses grandes ou moyennes ou normales - Simulation de Poinsot - Rglage du gain - axe du pin ',13,' Vitesse du spin - Choix possible de la simulation Bpoint seule ou en parallle avec la mise en spin',13,' ']],...
		'Font Name','Arial')
set_param([sys,'/',['Choix des paramtres de la simulation dans surv1dat.m',13,'',13,'- Vitesses grandes ou moyennes ou normales - Simulation de Poinsot - Rglage du gain - axe du pin ',13,' Vitesse du spin - Choix possible de la simulation Bpoint seule ou en parallle avec la mise en spin',13,' ']],...
		'Font Weight','bold')
set_param([sys,'/',['Choix des paramtres de la simulation dans surv1dat.m',13,'',13,'- Vitesses grandes ou moyennes ou normales - Simulation de Poinsot - Rglage du gain - axe du pin ',13,' Vitesse du spin - Choix possible de la simulation Bpoint seule ou en parallle avec la mise en spin',13,' ']],...
		'Font Size',12)
set_param([sys,'/',['Choix des paramtres de la simulation dans surv1dat.m',13,'',13,'- Vitesses grandes ou moyennes ou normales - Simulation de Poinsot - Rglage du gain - axe du pin ',13,' Vitesse du spin - Choix possible de la simulation Bpoint seule ou en parallle avec la mise en spin',13,' ']],...
		'position',[590,130,595,135])

add_block('built-in/Note',[sys,'/',['Choix possible du type de matrice d''inertie quelconque - diagonale - de rvolution',13,'NB : La direction du spin et la vitesse angulaire doivent tre choisis dans surv1dat.m']])
set_param([sys,'/',['Choix possible du type de matrice d''inertie quelconque - diagonale - de rvolution',13,'NB : La direction du spin et la vitesse angulaire doivent tre choisis dans surv1dat.m']],...
		'ForeGround',4)
set_param([sys,'/',['Choix possible du type de matrice d''inertie quelconque - diagonale - de rvolution',13,'NB : La direction du spin et la vitesse angulaire doivent tre choisis dans surv1dat.m']],...
		'Font Name','Arial Narrow')
set_param([sys,'/',['Choix possible du type de matrice d''inertie quelconque - diagonale - de rvolution',13,'NB : La direction du spin et la vitesse angulaire doivent tre choisis dans surv1dat.m']],...
		'Font Size',12)
set_param([sys,'/',['Choix possible du type de matrice d''inertie quelconque - diagonale - de rvolution',13,'NB : La direction du spin et la vitesse angulaire doivent tre choisis dans surv1dat.m']],...
		'position',[580,205,585,210])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[865,305,870,310])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[845,340,850,345])


%     Subsystem  'Subsystem3'.

new_system([sys,'/','Subsystem3'])
set_param([sys,'/','Subsystem3'],'Location',[0,40,1264,964])
open_system([sys,'/','Subsystem3'])

add_block('built-in/Note',[sys,'/',['Subsystem3/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Subsystem3/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[620,40,625,45])

add_block('built-in/Demux',[sys,'/','Subsystem3/Demux'])
set_param([sys,'/','Subsystem3/Demux'],...
		'outputs','[3 4]',...
		'position',[470,339,520,506])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem3/MATLAB Fcn1'])
set_param([sys,'/','Subsystem3/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[700,448,760,482])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace14'])
set_param([sys,'/','Subsystem3/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[965,490,1035,510])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace12'])
set_param([sys,'/','Subsystem3/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[965,420,1035,440])

add_block('built-in/Demux',[sys,'/','Subsystem3/Demux2'])
set_param([sys,'/','Subsystem3/Demux2'],...
		'outputs','3',...
		'position',[860,413,905,517])

add_block('built-in/Note',[sys,'/','Subsystem3/Energie'])
set_param([sys,'/','Subsystem3/Energie'],...
		'position',[885,390,890,395])

add_block('built-in/Note',[sys,'/','Subsystem3/Quaternion Q'])
set_param([sys,'/','Subsystem3/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[600,435,605,440])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace7'])
set_param([sys,'/','Subsystem3/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[850,370,920,390])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem3/MATLAB Fcn3'])
set_param([sys,'/','Subsystem3/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','ENERGIE(u)',...
		'Output Width','1',...
		'position',[745,361,825,399])

add_block('built-in/Fcn',[sys,'/','Subsystem3/Fcn'])
set_param([sys,'/','Subsystem3/Fcn'],...
		'ForeGround',1,...
		'BackGround',2,...
		'Expr','(u(1)^2+u(2)^2)^0.5',...
		'position',[720,325,760,345])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace9'])
set_param([sys,'/','Subsystem3/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'mat-name','p2plusq2',...
		'buffer','points_trace',...
		'position',[805,325,875,345])

add_block('built-in/Inport',[sys,'/','Subsystem3/in_1'])
set_param([sys,'/','Subsystem3/in_1'],...
		'position',[400,415,420,435])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace13'])
set_param([sys,'/','Subsystem3/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[965,455,1035,475])

add_block('built-in/To File',[sys,'/','Subsystem3/To File'])
set_param([sys,'/','Subsystem3/To File'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','roulis',...
		'position',[1115,377,1205,423])

add_block('built-in/To File',[sys,'/','Subsystem3/To File1'])
set_param([sys,'/','Subsystem3/To File1'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','tangage',...
		'position',[1115,427,1205,473])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace8'])
set_param([sys,'/','Subsystem3/To Workspace8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[965,525,1035,545])

add_block('built-in/To File',[sys,'/','Subsystem3/To File2'])
set_param([sys,'/','Subsystem3/To File2'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','lacet',...
		'position',[1115,492,1205,538])

add_block('built-in/To File',[sys,'/','Subsystem3/To File3'])
set_param([sys,'/','Subsystem3/To File3'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','temps',...
		'position',[1115,547,1205,593])

add_block('built-in/Clock',[sys,'/','Subsystem3/Clock'])
set_param([sys,'/','Subsystem3/Clock'],...
		'position',[905,525,925,545])

add_block('built-in/Demux',[sys,'/','Subsystem3/Demux3'])
set_param([sys,'/','Subsystem3/Demux3'],...
		'outputs','3',...
		'position',[610,158,655,262])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace15'])
set_param([sys,'/','Subsystem3/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[715,165,785,185])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace16'])
set_param([sys,'/','Subsystem3/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[715,200,785,220])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace17'])
set_param([sys,'/','Subsystem3/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[715,235,785,255])

add_block('built-in/Note',[sys,'/',['Subsystem3/Reste  sortir les angles',13,'',13,'']])
set_param([sys,'/',['Subsystem3/Reste  sortir les angles',13,'',13,'']],...
		'position',[235,230,240,235])

add_block('built-in/Note',[sys,'/','Subsystem3/Reste  mettre un stop'])
set_param([sys,'/','Subsystem3/Reste  mettre un stop'],...
		'position',[235,205,240,210])

add_block('built-in/Note',[sys,'/',['Subsystem3/Mettre une saturation',13,'',13,'']])
set_param([sys,'/',['Subsystem3/Mettre une saturation',13,'',13,'']],...
		'position',[230,255,235,260])

add_block('built-in/Note',[sys,'/','Subsystem3/Mettre des filtres'])
set_param([sys,'/','Subsystem3/Mettre des filtres'],...
		'position',[225,310,230,315])

add_block('built-in/Note',[sys,'/','Subsystem3/Mettre des retards'])
set_param([sys,'/','Subsystem3/Mettre des retards'],...
		'position',[230,280,235,285])

add_block('built-in/Note',[sys,'/','Subsystem3/CAS DE POINSOT AVEC'])
set_param([sys,'/','Subsystem3/CAS DE POINSOT AVEC'],...
		'ForeGround',2,...
		'BackGround',2,...
		'Font Weight','bold',...
		'position',[960,305,965,310])

add_block('built-in/Note',[sys,'/','Subsystem3/Matrice rvolution autour lacet'])
set_param([sys,'/','Subsystem3/Matrice rvolution autour lacet'],...
		'ForeGround',2,...
		'BackGround',2,...
		'Font Weight','bold',...
		'position',[1130,280,1135,285])

add_block('built-in/Note',[sys,'/','Subsystem3/Pas de perturbations'])
set_param([sys,'/','Subsystem3/Pas de perturbations'],...
		'ForeGround',2,...
		'BackGround',2,...
		'Font Weight','bold',...
		'position',[1105,305,1110,310])

add_block('built-in/Note',[sys,'/','Subsystem3/Pas de couples rgulateurs'])
set_param([sys,'/','Subsystem3/Pas de couples rgulateurs'],...
		'ForeGround',2,...
		'BackGround',2,...
		'Font Weight','bold',...
		'position',[1130,330,1135,335])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace10'])
set_param([sys,'/','Subsystem3/To Workspace10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'mat-name','omega_tmc',...
		'buffer','points_trace',...
		'position',[785,297,885,323])

add_block('built-in/Fcn',[sys,'/','Subsystem3/Fcn1'])
set_param([sys,'/','Subsystem3/Fcn1'],...
		'ForeGround',1,...
		'BackGround',2,...
		'Expr','(Ir^2*u(1)^2+It^2*u(2)^2+Il^2*u(3)^2)^0.5',...
		'position',[725,265,765,285])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace18'])
set_param([sys,'/','Subsystem3/To Workspace18'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'mat-name','momcin',...
		'buffer','points_trace',...
		'position',[825,265,895,285])

add_block('built-in/To File',[sys,'/','Subsystem3/To File4'])
set_param([sys,'/','Subsystem3/To File4'],...
		'orientation',2,...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'File name','initpqrQ.mat',...
		'Matrix name','initpqrQ')
set_param([sys,'/','Subsystem3/To File4'],...
		'position',[190,374,400,416])

add_block('built-in/Note',[sys,'/',['Subsystem3/Transmission des donnes',13,'initiales pour la simulation',13,'suivante']])
set_param([sys,'/',['Subsystem3/Transmission des donnes',13,'initiales pour la simulation',13,'suivante']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[290,440,295,445])

add_block('built-in/Note',[sys,'/',['Subsystem3/Entre de',13,'p q r Q']])
set_param([sys,'/',['Subsystem3/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[420,325,425,330])


%     Subsystem  'Subsystem3/Graph'.

new_system([sys,'/','Subsystem3/Graph'])
set_param([sys,'/','Subsystem3/Graph'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Subsystem3/Graph/x'])
set_param([sys,'/','Subsystem3/Graph/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Subsystem3/Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem3/Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Subsystem3/Graph'],[90,65;125,65])
set_param([sys,'/','Subsystem3/Graph'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Subsystem3/Graph'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Subsystem3/Graph'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Subsystem3/Graph'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Subsystem3/Graph'],...
		'Mask Entries','30000\/-0.1\/0.1\/''y-/m--/c-./w:/g*/ro/b+''\/')


%     Finished composite block 'Subsystem3/Graph'.

set_param([sys,'/','Subsystem3/Graph'],...
		'orientation',2,...
		'position',[425,187,480,233])

add_block('built-in/Gain',[sys,'/','Subsystem3/Gain'])
set_param([sys,'/','Subsystem3/Gain'],...
		'Gain','Asat(2,2)',...
		'position',[820,171,875,219])

add_block('built-in/Gain',[sys,'/',['Subsystem3/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Subsystem3/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[790,452,815,478])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace19'])
set_param([sys,'/','Subsystem3/To Workspace19'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','moment_cinetique_2',...
		'buffer','points_trace',...
		'position',[910,182,1055,208])

add_block('built-in/Note',[sys,'/',['Subsystem3/Vitesses angulaires absolues',13,'autour des axes x y z']])
set_param([sys,'/',['Subsystem3/Vitesses angulaires absolues',13,'autour des axes x y z']],...
		'position',[785,120,790,125])

add_block('built-in/Fcn',[sys,'/','Subsystem3/Fcn3'])
set_param([sys,'/','Subsystem3/Fcn3'],...
		'Expr','(u(1)^2+u(3)^2)^0.5',...
		'position',[690,99,770,131])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace21'])
set_param([sys,'/','Subsystem3/To Workspace21'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_precession',...
		'buffer','points_trace',...
		'position',[925,102,1070,128])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace22'])
set_param([sys,'/','Subsystem3/To Workspace22'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','coord_Y_sur_z',...
		'buffer','points_trace',...
		'position',[925,654,1045,676])

add_block('built-in/Fcn',[sys,'/','Subsystem3/Fcn4'])
set_param([sys,'/','Subsystem3/Fcn4'],...
		'Expr','2*(u(3)*u(4)-u(1)*u(2))',...
		'position',[805,649,885,681])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace20'])
set_param([sys,'/','Subsystem3/To Workspace20'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','angle_y_Y',...
		'buffer','points_trace',...
		'position',[935,690,1005,710])

add_block('built-in/Fcn',[sys,'/','Subsystem3/Fcn2'])
set_param([sys,'/','Subsystem3/Fcn2'],...
		'Expr','acos(0.9999*2*(u(1)^2+u(3)^2)-1)',...
		'position',[805,684,885,716])

add_block('built-in/Inport',[sys,'/','Subsystem3/in_2'])
set_param([sys,'/','Subsystem3/in_2'],...
		'Port','2',...
		'position',[390,755,410,775])

add_block('built-in/Demux',[sys,'/','Subsystem3/Demux1'])
set_param([sys,'/','Subsystem3/Demux1'],...
		'outputs','[3 4]',...
		'position',[470,679,520,846])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace11'])
set_param([sys,'/','Subsystem3/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[915,764,1000,796])

add_block('built-in/Note',[sys,'/','Subsystem3/Q'])
set_param([sys,'/','Subsystem3/Q'],...
		'position',[705,730,710,735])

add_block('built-in/Note',[sys,'/',['Subsystem3/Q''']])
set_param([sys,'/',['Subsystem3/Q''']],...
		'position',[710,810,715,815])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux'])
set_param([sys,'/','Subsystem3/Mux'],...
		'inputs','[4 4]',...
		'position',[735,731,770,829])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace5'])
set_param([sys,'/','Subsystem3/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[565,702,670,738])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem3/MATLAB Fcn4'])
set_param([sys,'/','Subsystem3/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[815,761,895,799])

add_block('built-in/Note',[sys,'/',['Subsystem3/Rotation satellite relative par',13,'rapport aux axes orbitaux',13,'exprime sur les axes ',13,'d''criture du quaternion, donc ',13,'les axes orbitaux X Y Z']])
set_param([sys,'/',['Subsystem3/Rotation satellite relative par',13,'rapport aux axes orbitaux',13,'exprime sur les axes ',13,'d''criture du quaternion, donc ',13,'les axes orbitaux X Y Z']],...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['Subsystem3/Rotation satellite relative par',13,'rapport aux axes orbitaux',13,'exprime sur les axes ',13,'d''criture du quaternion, donc ',13,'les axes orbitaux X Y Z']],...
		'Font Size',12)
set_param([sys,'/',['Subsystem3/Rotation satellite relative par',13,'rapport aux axes orbitaux',13,'exprime sur les axes ',13,'d''criture du quaternion, donc ',13,'les axes orbitaux X Y Z']],...
		'position',[905,810,910,815])

add_block('built-in/Note',[sys,'/','Subsystem3/Drive de Q'])
set_param([sys,'/','Subsystem3/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[635,805,640,810])

add_block('built-in/Fcn',[sys,'/','Subsystem3/Fcn5'])
set_param([sys,'/','Subsystem3/Fcn5'],...
		'hide name',0,...
		'Expr','2*(u(2)*u(3)+u(1)*u(4))',...
		'position',[805,614,885,646])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace23'])
set_param([sys,'/','Subsystem3/To Workspace23'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','coord_Y_sur_x',...
		'buffer','points_trace',...
		'position',[925,619,1045,641])
add_line([sys,'/','Subsystem3'],[525,380;740,380])
add_line([sys,'/','Subsystem3'],[830,380;845,380])
add_line([sys,'/','Subsystem3'],[425,425;465,425])
add_line([sys,'/','Subsystem3'],[525,465;695,465])
add_line([sys,'/','Subsystem3'],[930,535;960,535])
add_line([sys,'/','Subsystem3'],[660,380;660,335;715,335])
add_line([sys,'/','Subsystem3'],[765,335;800,335])
add_line([sys,'/','Subsystem3'],[660,335;660,310;780,310])
add_line([sys,'/','Subsystem3'],[415,765;465,765])
add_line([sys,'/','Subsystem3'],[525,720;560,720])
add_line([sys,'/','Subsystem3'],[525,805;730,805])
add_line([sys,'/','Subsystem3'],[675,465;675,755;730,755])
add_line([sys,'/','Subsystem3'],[775,780;810,780])
add_line([sys,'/','Subsystem3'],[900,780;910,780])
add_line([sys,'/','Subsystem3'],[765,465;785,465])
add_line([sys,'/','Subsystem3'],[820,465;855,465])
add_line([sys,'/','Subsystem3'],[910,430;960,430])
add_line([sys,'/','Subsystem3'],[910,465;960,465])
add_line([sys,'/','Subsystem3'],[910,500;960,500])
add_line([sys,'/','Subsystem3'],[945,430;945,400;1110,400])
add_line([sys,'/','Subsystem3'],[943,465;945,450;1110,450])
add_line([sys,'/','Subsystem3'],[945,500;945,515;1110,515])
add_line([sys,'/','Subsystem3'],[930,535;930,570;1110,570])
add_line([sys,'/','Subsystem3'],[550,380;550,210;605,210])
add_line([sys,'/','Subsystem3'],[660,175;710,175])
add_line([sys,'/','Subsystem3'],[660,210;710,210])
add_line([sys,'/','Subsystem3'],[660,245;710,245])
add_line([sys,'/','Subsystem3'],[660,310;660,275;720,275])
add_line([sys,'/','Subsystem3'],[770,275;820,275])
add_line([sys,'/','Subsystem3'],[445,425;445,395;405,395])
add_line([sys,'/','Subsystem3'],[550,210;485,210])
add_line([sys,'/','Subsystem3'],[695,210;694,209;694,195;815,195])
add_line([sys,'/','Subsystem3'],[675,700;800,700])
add_line([sys,'/','Subsystem3'],[890,700;930,700])
add_line([sys,'/','Subsystem3'],[585,210;585,115;685,115])
add_line([sys,'/','Subsystem3'],[775,115;920,115])
add_line([sys,'/','Subsystem3'],[880,195;905,195])
add_line([sys,'/','Subsystem3'],[890,665;920,665])
add_line([sys,'/','Subsystem3'],[675,665;800,665])
add_line([sys,'/','Subsystem3'],[890,630;920,630])
add_line([sys,'/','Subsystem3'],[675,630;800,630])
set_param([sys,'/','Subsystem3'],...
		'Mask Display','SORTIE DES VARIABLES\n\nANGLES EN DEGRES\n\nENERGIE...')


%     Finished composite block 'Subsystem3'.

set_param([sys,'/','Subsystem3'],...
		'hide name',0,...
		'position',[925,316,1120,389])


%     Subsystem  'Extras29'.

new_system([sys,'/','Extras29'])
set_param([sys,'/','Extras29'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras29'],...
		'Mask Display','Energie produite\n\n en spin de Laurens',...
		'Mask Dialogue','eval(''plot(temps,energie_spin,''''y'''');text(200,50000,[''''Pm = '''' num2str(puissance_moyenne(length(q))) '''' W'''']);grid;figure(gcf)'')')


%     Finished composite block 'Extras29'.

set_param([sys,'/','Extras29'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[295,800,470,866])


%     Subsystem  'Extras30'.

new_system([sys,'/','Extras30'])
set_param([sys,'/','Extras30'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras30'],...
		'Mask Display','Puissance\n\n instantane',...
		'Mask Dialogue','eval(''plot(temps,puissance_inst,''''y'''');text(200,50000,[''''Pm = '''' num2str(puissance_moyenne(length(q))) '''' W'''']);grid;figure(gcf)'')')


%     Finished composite block 'Extras30'.

set_param([sys,'/','Extras30'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[485,800,630,861])


%     Subsystem  'Extras14'.

new_system([sys,'/','Extras14'])
set_param([sys,'/','Extras14'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras14'],...
		'Mask Display','Voir projection\n\nde Y sur plan  (x,z)',...
		'Mask Dialogue','eval(''plot(coord_Y_sur_x,coord_Y_sur_z);grid;figure(gcf)'')')


%     Finished composite block 'Extras14'.

set_param([sys,'/','Extras14'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[635,795,805,861])


%     Subsystem  'Extras16'.

new_system([sys,'/','Extras16'])
set_param([sys,'/','Extras16'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras16'],...
		'Mask Display','Voir projection\npartielle ( fin )\nde Y sur plan  (x,z)',...
		'Mask Dialogue','eval(''N=length(q);plot(coord_Y_sur_x(N-1000:N),coord_Y_sur_z(N-1000:N));grid;figure(gcf)'')')


%     Finished composite block 'Extras16'.

set_param([sys,'/','Extras16'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[810,795,985,866])


%     Subsystem  'Extras17'.

new_system([sys,'/','Extras17'])
set_param([sys,'/','Extras17'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras17'],...
		'Mask Display','Voir projection\npartielle ( fin courte )\nde Y sur plan  (x,z)')
set_param([sys,'/','Extras17'],...
		'Mask Dialogue','eval(''N=length(q);plot(coord_Y_sur_x(N-300:N),coord_Y_sur_z(N-300:N));text(-0.05,0.05,[num2str(temps(N-300)) ''''  '''' num2str(temps(N)) '''' s'''']);grid;figure(gcf)'')')


%     Finished composite block 'Extras17'.

set_param([sys,'/','Extras17'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1005,795,1180,866])
add_line(sys,[750,440;890,440;890,595;60,595;60,510;95,510])
add_line(sys,[525,440;640,440])
add_line(sys,[330,365;455,365])
add_line(sys,[320,510;455,510])
add_line(sys,[770,440;770,335;920,335])
add_line(sys,[620,440;620,370;920,370])
add_line(sys,[60,510;60,365;95,365])
add_line(sys,[565,595;565,525;605,525])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
